@@ -1,7 +1,6 @@
 from dbtemplates.models import Template
 from df_notifications.models import NotificationHistory
 from df_notifications.tasks import send_notification_async
-from df_notifications.utils import render_block
 from df_notifications.utils import send_notification
 from django.contrib.auth import get_user_model
 from django.utils import timezone
@@ -17,25 +16,30 @@ User = get_user_model()
 pytestmark = [pytest.mark.django_db]
 
 
+def setup_templates():
+    Template.objects.create(
+        name="df_notifications/posts/published/subject.txt",
+        content="New post: {{ instance.title }}",
+    )
+    Template.objects.create(
+        name="df_notifications/posts/published/body.txt",
+        content="{{ instance.description }}",
+    )
+
+
 def setup_published_notification():
     action = PostNotificationRule(
         is_published_next=True,
         is_published_prev=False,
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefix="df_notifications/posts/published/",
     )
     action.save()
-    Template.objects.create(
-        name="df_notifications/posts/published.html",
-        content="""
-            {% block subject %}New post: {{ instance.title }}{% endblock %}
-            {% block body %}{{ instance.description }}{% endblock %}
-        """,
-    )
 
 
 def test_post_published_notification_created():
     setup_published_notification()
+    setup_templates()
 
     user = User.objects.create(
         email="test@test.com",
@@ -49,12 +53,13 @@ def test_post_published_notification_created():
     notifications = NotificationHistory.objects.all()
     assert len(notifications) == 1
     notification = notifications[0]
-    assert notification.content["subject"] == f"New post: {post.title}"
-    assert notification.content["body"] == post.description
+    assert notification.content["subject.txt"] == f"New post: {post.title}"
+    assert notification.content["body.txt"] == post.description
 
 
 def test_post_non_published_notification_not_created():
     setup_published_notification()
+    setup_templates()
 
     user = User.objects.create(
         email="test@test.com",
@@ -70,6 +75,7 @@ def test_post_non_published_notification_not_created():
 
 def test_notification_history_queryset_for_instance_filtering():
     setup_published_notification()
+    setup_templates()
 
     user = User.objects.create(
         email="test@test.com",
@@ -90,14 +96,15 @@ def test_notification_history_queryset_for_instance_filtering():
     notifications = NotificationHistory.objects.for_instance(post1)
     assert len(notifications) == 1
     notification = notifications[0]
-    assert notification.content["body"] == post1.description
+    assert notification.content["body.txt"] == post1.description
 
 
 def test_reminder_queryset_is_valid():
+    setup_templates()
     reminder = PostNotificationReminder(
         is_published=True,
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefix="df_notifications/posts/published/",
     )
     reminder.save()
 
@@ -117,10 +124,11 @@ def test_reminder_queryset_is_valid():
 
 
 def test_reminder_respect_delay():
+    setup_templates()
     reminder = PostNotificationReminder(
         is_published=True,
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefix="df_notifications/posts/published/",
         delay=timezone.timedelta(seconds=60),
     )
     reminder.save()
@@ -141,10 +149,11 @@ def test_reminder_respect_delay():
 
 
 def test_reminder_performs_retries():
+    setup_templates()
     reminder = PostNotificationReminder(
         is_published=True,
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefix="df_notifications/posts/published/",
         repeat=2,
         cooldown=timezone.timedelta(seconds=0),
         delay=timezone.timedelta(seconds=0),
@@ -170,27 +179,29 @@ def test_reminder_performs_retries():
 
 
 def test_send_notification_without_model():
+    Template.objects.create(
+        name="df_notifications/posts/published/subject.txt",
+        content="New post: {{ title }}",
+    )
+    Template.objects.create(
+        name="df_notifications/posts/published/body.txt",
+        content="{{ description }}",
+    )
     user = User.objects.create(
         email="test@test.com",
     )
-    Template.objects.create(
-        name="df_notifications/posts/published.html",
-        content="""
-            {% block subject %}New post: {{ title }}{% endblock %}
-            {% block body__console %}{{ description }}{% endblock %}
-        """,
-    )
+
     notification = send_notification(
         users=[user],
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefixes="df_notifications/posts/published/",
         context={
             "title": "title 123",
             "description": "description 456",
         },
     )
-    assert notification.content["subject"] == "New post: title 123"
-    assert notification.content["body"] == "description 456"
+    assert notification.content["subject.txt"] == "New post: title 123"
+    assert notification.content["body.txt"] == "description 456"
 
 
 def test_send_notification_async_without_model():
@@ -198,16 +209,18 @@ def test_send_notification_async_without_model():
         email="test@test.com",
     )
     Template.objects.create(
-        name="df_notifications/posts/published.html",
-        content="""
-                {% block subject %}New post: {{ title }}{% endblock %}
-                {% block body %}{{ description }}{% endblock %}
-            """,
+        name="df_notifications/posts/published/subject.txt",
+        content="New post: {{ title }}",
     )
+    Template.objects.create(
+        name="df_notifications/posts/published/body.txt",
+        content="{{ description }}",
+    )
+
     send_notification_async(
         [user.id],
         "console",
-        "df_notifications/posts/published.html",
+        "df_notifications/posts/published/",
         {
             "title": "title 123",
             "description": "description 456",
@@ -216,22 +229,16 @@ def test_send_notification_async_without_model():
     notifications = NotificationHistory.objects.all()
     assert len(notifications) == 1
     notification = notifications[0]
-    assert notification.content["subject"] == "New post: title 123"
-    assert notification.content["body"] == "description 456"
+    assert notification.content["subject.txt"] == "New post: title 123"
+    assert notification.content["body.txt"] == "description 456"
 
 
 def test_reminder_performs_action():
-    Template.objects.create(
-        name="df_notifications/posts/published.html",
-        content="""
-                {% block subject %}New post: {{ title }}{% endblock %}
-                {% block body__console %}{{ description }}{% endblock %}
-            """,
-    )
+    setup_templates()
     reminder = PostNotificationReminder(
         is_published=True,
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefix="df_notifications/posts/published/",
         action="instance.title='new title'; instance.save()",
     )
     reminder.save()
@@ -251,11 +258,12 @@ def test_reminder_performs_action():
 
 
 def test_rule_not_invoked_on_non_tracked_field_change():
+    setup_templates()
     action = PostNotificationRule(
         is_published_next=True,
         is_published_prev=None,
         channel="console",
-        template="df_notifications/posts/published.html",
+        template_prefix="df_notifications/posts/published/",
     )
     action.save()
 
@@ -280,23 +288,28 @@ def test_rule_not_invoked_on_non_tracked_field_change():
     assert len(NotificationHistory.objects.all()) == 2
 
 
-def test_render_block_block_nested():
+def test_default_templates_rendered_if_no_template_exists():
     Template.objects.create(
-        name="t1.html",
-        content="""
-            {% block subject %}subj1{% endblock %}
-        """,
+        name="test_app/df_notifications/posts/subject.txt",
+        content="New post: {{ instance.title }}",
     )
     Template.objects.create(
-        name="t2.html",
-        content="""
-            {% extends 't1.html' %}
-        """,
+        name="test_app/df_notifications/posts/body.txt",
+        content="{{ instance.description }}",
     )
-    Template.objects.create(
-        name="t3.html",
-        content="""
-            {% extends 't2.html' %}
-        """,
+    setup_published_notification()
+
+    user = User.objects.create(
+        email="test@test.com",
     )
-    assert render_block("t3.html", "subject", {}) == "subj1"
+    post = Post.objects.create(
+        title="Title 1",
+        description="Content 1",
+        is_published=True,
+        author=user,
+    )
+    notifications = NotificationHistory.objects.all()
+    assert len(notifications) == 1
+    notification = notifications[0]
+    assert notification.content["subject.txt"] == f"New post: {post.title}"
+    assert notification.content["body.txt"] == post.description
